# Muteract
Interactive and Iterative Prompt Mutation Interface for LLM Developers and Evaluators
![Screenshot of the Muteract User Interface](images/UI.png "Muteract User Interface")

## Installation
Ensure Python 3.10 or above and Node.js v22.3.0 or above are installed.
Clone this repository and run the following commands in the root folder of the repository:
```
pip install -r requirements.txt
npm install
```
After this is done, add the OpenAI API Key in the script `start.sh`.
Then run the script using:
```
chmod +x start.sh
./start.sh
```
